X-Git-Url: https://scm.cri.minesparis.psl.eu/git/linpy.git/blobdiff_plain/9b755b94aa2c8847ffca607de239f5c3bca9984b..4162c0430092e0ba2b8d8d62b5de24cdd71abe3b:/setup.py

diff --git a/setup.py b/setup.py
index f72af50..609b2b9 100755
--- a/setup.py
+++ b/setup.py
@@ -2,31 +2,36 @@
 
 # Copyright 2014 MINES ParisTech
 #
 # This file is part of Linpy.
 #
 # Linpy is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # Linpy is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with Linpy.  If not, see <http://www.gnu.org/licenses/>.
+# along with LinPy.  If not, see <http://www.gnu.org/licenses/>.
 
 from distutils.core import setup, Extension
 
+with open('linpy/_version.py') as file:
+    exec(file.read())
+
 setup(
-    name='pypol',
-    description='A polyhedral library based on ISL',
+    name='LinPy',
+    version=__version__,
+    description='A polyhedral library based on isl',
     author='MINES ParisTech',
-    packages=['pypol'],
+    url='https://scm.cri.mines-paristech.fr/git/linpy.git',
+    packages=['linpy'],
     ext_modules = [
-        Extension('pypol._islhelper',
-            sources=['pypol/_islhelper.c'],
+        Extension('linpy._islhelper',
+            sources=['linpy/_islhelper.c'],
             libraries=['isl'])
     ]
 )
@@ -2,31 +2,36 @@
 # Copyright 2014 MINES ParisTech
 #
-# This file is part of Linpy.
+# This file is part of LinPy.
 #
@@ -2,31 +2,36 @@
 #
-# Linpy is free software: you can redistribute it and/or modify
+# LinPy is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
@@ -2,31 +2,36 @@
 # (at your option) any later version.
 #
-# Linpy is distributed in the hope that it will be useful,
+# LinPy is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the